@@ -80,7 +80,8 @@ class ClassificationPredictor(BasePredictor):
             for items in proc.preprocess({"task": input_args['task'], "input": input_args['input']}):
                 feature = proc.postprocess({**items, **{'task_dict': self.model.tasks}}, self.model.tokenizer,
                                            self.model.maxlen)
-            predictions = self.model.forward(dict((k, v.unsqueeze(0)) for k, v in feature.items()), eval=True)
+            feature = proc.postprocess_batch(feature)
+            predictions = self.model.forward(feature, eval=True)
             if input_args['topK'] < 2:
                 ret_result.append(
                     [i[input_args['task']] for i in predictions['max_item'] if input_args['task'] in i][0])
